Cadishi is developed by

* Klaus Reuter, klaus.reuter@mpcdf.mpg.de
* Jürgen Köfinger, juergen.koefinger@biophys.mpg.de

Moreover, the following people contributed to Cadishi:

2016

* Max Linke, max.linke@biophys.mpg.de
